as.data.frame.r4vn_machine: Convert a tabmachine result to a data frame

as.data.frame.r4vn_machineR Documentation

Convert a tabmachine result to a data frame

Description

Convert a tabmachine result to a data frame

Usage

## S3 method for class 'r4vn_machine'
as.data.frame(x, ...)

Arguments

x

A r4vn_machine object.

...

Unused.

Value

A data frame containing the final evaluation performance stored in x$performance. Each row represents a model/metric combination and reports the evaluation data set, method, metric, estimate, confidence limits when available, and the confidence-interval method.


R4VN documentation built on Sept. 30, 2026, 5:13 p.m.