dengue_its_control: Example controlled interrupted time-series data

dengue_its_controlR Documentation

Example controlled interrupted time-series data

Description

Synthetic long-format controlled ITS dataset with a Control and an Intervention series observed monthly over the same 96-month period.

Usage

data(dengue_its_control)

Format

A data frame with 192 rows and 7 variables:

month

Monthly date.

group

Control or Intervention series.

cases

Synthetic monthly case count.

rainfall

Synthetic monthly rainfall in mm.

temperature

Synthetic mean monthly temperature in degrees C.

population

Synthetic population denominator.

intervention

Indicator used for teaching; intervention applies to the Intervention group from January 2023 onward.

Synthetic data generated for R4VN examples.


R4VN documentation built on Sept. 30, 2026, 5:13 p.m.