mcc: Matched Case-control Analysis

View source: R/epi.R

mccR Documentation

Matched Case-control Analysis

Description

Calculates the matched odds ratio from the discordant pairs and an exact conditional confidence interval and p-value.

Usage

mcc(
  case,
  control,
  data = NULL,
  exposed = NULL,
  level = 0.95,
  digits = 3,
  p_digits = 3,
  show = TRUE,
  console = FALSE
)

mcci(
  a,
  b,
  c,
  d,
  level = 0.95,
  digits = 3,
  p_digits = 3,
  show = TRUE,
  console = FALSE
)

Arguments

case, control

Paired binary exposure variables for cases and controls.

data

Data frame. If NULL, active data is used.

exposed

Exposure level; defaults to the last observed level.

level

Confidence level.

digits, p_digits

Decimal places for estimates and p-values.

show

Logical; open the formatted result in the Viewer. Default TRUE.

console

Logical; also print the traditional text result in the Console. Default FALSE.

a, b, c, d

Matched-pair table cells. The matched odds ratio is b/c.

Value

Invisibly returns an object of class r4vn_stat.

Examples

mcci(20, 14, 5, 31)

R4VN documentation built on Sept. 30, 2026, 5:13 p.m.