plot.r4vn_tabforest: Plot an R4VN regression forest object

View source: R/tabforest.R

plot.r4vn_tabforestR Documentation

Plot an R4VN regression forest object

Description

Re-draws a tabforest() object without refitting models. All graphical settings may be overridden here, which is useful for trying different journal layouts after the analysis is finalized.

Usage

## S3 method for class 'r4vn_tabforest'
plot(x, ..., file = NULL, width = NULL, height = NULL, dpi = NULL)

Arguments

x

An r4vn_tabforest object.

...

Any plotting option accepted by tabforest().

file, width, height, dpi

Optional output overrides.

Value

x, invisibly.


R4VN documentation built on Sept. 30, 2026, 5:13 p.m.