plot.r4vn_tabscale: Plot diagnostics from a scale analysis

plot.r4vn_tabscaleR Documentation

Plot diagnostics from a scale analysis

Description

Displays every available tabscale graphic in the R graphics device. In RStudio, use the back/forward arrows in the Plots pane to review them.

Usage

## S3 method for class 'r4vn_tabscale'
plot(x, which = NULL, ...)

Arguments

x

An object created by tabscale().

which

Optional plot names or indices. The default displays all plots.

...

Additional arguments currently ignored.

Value

The input object, invisibly.


R4VN documentation built on Sept. 30, 2026, 5:13 p.m.