| as.data.frame.r4vn_machine | R Documentation |
Convert a tabmachine result to a data frame
## S3 method for class 'r4vn_machine'
as.data.frame(x, ...)
x |
A |
... |
Unused. |
A data frame containing the final evaluation performance stored in
x$performance. Each row represents a model/metric combination and reports
the evaluation data set, method, metric, estimate, confidence limits when
available, and the confidence-interval method.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.