| distlearn | R Documentation |
Launches an interactive Shiny application for learning probability
distributions. The interface is inspired by the idea of a distribution
explorer, but is designed around the R4VN teaching workflow: change
parameters, immediately see the distribution, calculate commonly used
probability statements, read historical and practical context, simulate
data, and copy an equivalent distdata() command.
distlearn(
distribution = "normal",
launch.browser = interactive(),
port = NULL,
host = "127.0.0.1"
)
distribution |
Initial distribution name. Defaults to |
launch.browser |
Passed to |
port |
Optional port passed to |
host |
Host passed to |
The Studio currently includes the continuous distributions Normal, Log-normal, Uniform, Exponential, Gamma, Beta, Chi-square, Student's t, F, Weibull, Logistic, Cauchy, Laplace, Gumbel, Pareto, Rayleigh, Triangular, Kumaraswamy, Log-logistic, and Half-normal; and the discrete distributions Bernoulli, Binomial, Poisson, Geometric, Negative binomial, Hypergeometric, Discrete uniform, Beta-binomial, Zero-inflated Poisson, finite Zipf, and Logarithmic series.
Each distribution has an interactive probability/density plot and CDF, numerical characteristics, parameter explanations, a historical note, typical applications, cautions, probability/quantile calculation, and simulation. Parameter values may be controlled with sliders or typed directly using numeric inputs.
Invisibly returns the result of shiny::runApp() when the app exits.
if (interactive()) {
distlearn("binomial")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.