| mcc | R Documentation |
Calculates the matched odds ratio from the discordant pairs and an exact conditional confidence interval and p-value.
mcc(
case,
control,
data = NULL,
exposed = NULL,
level = 0.95,
digits = 3,
p_digits = 3,
show = TRUE,
console = FALSE
)
mcci(
a,
b,
c,
d,
level = 0.95,
digits = 3,
p_digits = 3,
show = TRUE,
console = FALSE
)
case, control |
Paired binary exposure variables for cases and controls. |
data |
Data frame. If |
exposed |
Exposure level; defaults to the last observed level. |
level |
Confidence level. |
digits, p_digits |
Decimal places for estimates and p-values. |
show |
Logical; open the formatted result in the Viewer. Default |
console |
Logical; also print the traditional text result in the Console. Default |
a, b, c, d |
Matched-pair table cells. The matched odds ratio is |
Invisibly returns an object of class r4vn_stat.
mcci(20, 14, 5, 31)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.