| predict.r4vn_machine | R Documentation |
Predict from a tabmachine model
## S3 method for class 'r4vn_machine'
predict(
object,
newdata,
type = c("response", "prob", "class"),
threshold = NULL,
...
)
object |
A fitted |
newdata |
New predictor data. |
type |
|
threshold |
Optional binary threshold overriding the training-derived final threshold. |
... |
Unused. |
Predictions whose structure depends on the task and type. For a
regression task, a numeric vector of predicted outcomes is returned. For a
binary task, type = "response" or "prob" returns a numeric vector of
probabilities for the modeled event, while type = "class" returns a
factor of predicted classes. For a multiclass task, type = "response"
or "prob" returns a numeric matrix of class probabilities and
type = "class" returns a factor of predicted classes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.